Learn R Programming

radtools (version 1.0.6)

dicom_header_tag: Get DICOM header tag string corresponding to a group and element

Description

Get DICOM header tag string corresponding to a group and element

Usage

dicom_header_tag(group, element)

Arguments

group

Group e.g. "0008"

element

Element e.g. "0020"

Value

The tag e.g. "(0008,0020)"

Examples

Run this code
# NOT RUN {
dicom_header_tag("0008", "0020")
# }

Run the code above in your browser using DataLab