mat_reduce_dim: Take a slice of a multidimensional array by fixing the coordinates in the last dimension(s)
Description
Take a slice of a multidimensional array by fixing the coordinates in the last dimension(s)
Usage
mat_reduce_dim(mat, coords_last_dims)
Arguments
coords_last_dims
One or more coordinates in the last one or more dimensions of the matrix
Value
The reduced matrix with last dimension(s) collapsed